@@ -40,6 +40,9 @@ double  XLALSimLocateOmegaTime(
     INT4 use_optimized
     )
 {
+    /* check that retLenHi is at least 2 */
+    XLAL_CHECK_ABORT( retLenHi > 2 && "retLenHi must be greater than 2" );
+
     *tMaxOmega = 0; //Zach E: Fixes Heisenbug with ICC 16 and 17 compilers (5181); removing this line will result in segfaults with both compilers.
     /*
     * Locate merger point (max omega),
@@ -79,7 +82,7 @@ double  XLALSimLocateOmegaTime(
     timeHi.data = dynamicsHi->data;
 
     double dt = timeHi.data[1] - timeHi.data[0];
-    double ddradiusVec[timeHi.length - 1];
+    double XLAL_INIT_DECL(ddradiusVec, [timeHi.length - 1]);
     unsigned int k;
     for (k = 1; k < timeHi.length-1; k++) {
         ddradiusVec[k] = (radiusVec->data[k+1] - 2.*radiusVec->data[k] + radiusVec->data[k-1])/dt/dt;
@@ -437,8 +440,12 @@ double XLALSimLocateAmplTime(
     if (debugPK) {debugRD = 0;}
 
     double dt = timeHi->data[1] - timeHi->data[0];
-    double ddradiusVec[timeHi->length - 1];
+    double XLAL_INIT_DECL(ddradiusVec, [timeHi->length - 1]);
     unsigned int k;
+
+    /* check that timeHi->length is at least 2 */
+    XLAL_CHECK_ABORT( timeHi->length > 2 && "timeHi->length must be greater than 2" );
+
     for (k = 1; k < timeHi->length-1; k++) {
         ddradiusVec[k] = (radiusVec->data[k+1] - 2.*radiusVec->data[k] + radiusVec->data[k-1])/dt/dt;
 //        XLAL_PRINT_INFO("%3.10f %3.10f\n", timeHi->data[k], ddradiusVec[k]);
