@@ -13,8 +13,8 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with with program; see the file COPYING. If not, write to the
- *  Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
- *  MA  02111-1307  USA
+ *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA  02110-1301  USA
  */
 
 /**
@@ -112,7 +112,7 @@ static void NRHybSur3dq8_Init_LALDATA(void) {
 
     if (NRHybSur3dq8_IsSetup()) return;
 
-    char *path = XLALFileResolvePathLong(NRHybSur3dq8_DATAFILE, PKG_DATA_DIR);
+    char *path = XLAL_FILE_RESOLVE_PATH(NRHybSur3dq8_DATAFILE);
     if (path==NULL) {
         XLAL_ERROR_VOID(XLAL_ENOENT,
             "Unable to find data file %s in $LAL_DATA_PATH\n",
@@ -125,6 +125,7 @@ static void NRHybSur3dq8_Init_LALDATA(void) {
     char *file_path = XLALMalloc(size);
     snprintf(file_path, size, "%s/%s", dir, NRHybSur3dq8_DATAFILE);
 
+    #if LAL_HDF5_ENABLED
     LALH5File *file = XLALH5FileOpen(file_path, "r");
     if (file==NULL) {
         XLAL_ERROR_VOID(XLAL_EIO,
@@ -138,6 +139,9 @@ static void NRHybSur3dq8_Init_LALDATA(void) {
         XLAL_ERROR_VOID(XLAL_FAILURE, "Failure loading data from %s\n",
                 file_path);
     }
+    #else
+    XLAL_ERROR_VOID(XLAL_FAILURE,  "Failure loading data from %s\n. HDF5 support is not enabled.\n", file_path);
+    #endif
 
     XLALFree(path);
     XLALFree(file_path);
