@@ -13,8 +13,8 @@
 *
 *  You should have received a copy of the GNU General Public License
 *  along with with program; see the file COPYING. If not, write to the
-*  Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-*  MA  02111-1307  USA
+*  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+*  MA  02110-1301  USA
 */
 
 #include <stdio.h>
@@ -63,6 +63,9 @@ UNUSED static REAL8 XLALSimInspiralNRWaveformCheckFRef(
   UNUSED REAL8 fRef
 )
 {
+  #ifndef LAL_HDF5_ENABLED
+  XLAL_ERROR(XLAL_EFAILED, "HDF5 support not enabled");
+  #else
   gsl_vector *omega_w_vec = NULL;
   LALH5File *omega_group = NULL;
   REAL8 min_fref, lowest_arr_fref;
@@ -91,6 +94,7 @@ UNUSED static REAL8 XLALSimInspiralNRWaveformCheckFRef(
     }
   }
   return fRef;
+  #endif
 }
 
 UNUSED static REAL8 XLALSimInspiralNRWaveformGetRefTimeFromRefFreq(
@@ -115,9 +119,13 @@ UNUSED static REAL8 XLALSimInspiralNRWaveformGetRefTimeFromRefFreq(
   XLALH5FileClose(curr_group);
   acc = gsl_interp_accel_alloc();
   spline = gsl_spline_alloc(gsl_interp_cspline, omega_w_vec->size);
-  gsl_spline_init(spline, omega_w_vec->data, omega_t_vec->data,
+  INT4 status = gsl_spline_init(spline, omega_w_vec->data, omega_t_vec->data,
                   omega_t_vec->size);
+  XLAL_CHECK(status == GSL_SUCCESS, XLAL_FAILURE, "Failed gsl_spline_init evaluation. Probably omega_w is not monotonically increasing.\n");
   ref_time = gsl_spline_eval(spline, fRef * (LAL_MTSUN_SI * LAL_PI), acc);
+  if ( isnan(ref_time) ){
+    XLAL_ERROR(XLAL_FAILURE, "Interpolation error: gsl_spline_eval returning nan\n");
+  }
   gsl_vector_free(omega_t_vec);
   gsl_vector_free(omega_w_vec);
   gsl_spline_free(spline);
@@ -147,9 +155,13 @@ UNUSED static REAL8 XLALSimInspiralNRWaveformGetInterpValueFromGroupAtPoint(
   XLALH5FileClose(curr_group);
   acc = gsl_interp_accel_alloc();
   spline = gsl_spline_alloc(gsl_interp_cspline, curr_t_vec->size);
-  gsl_spline_init(spline, curr_t_vec->data, curr_y_vec->data,
+  INT4 status = gsl_spline_init(spline, curr_t_vec->data, curr_y_vec->data,
                   curr_t_vec->size);
+  XLAL_CHECK(status == GSL_SUCCESS, XLAL_FAILURE, "Failed gsl_spline_init evaluation. Probably omega_w is not monotonically increasing.\n");
   ret_val = gsl_spline_eval(spline, ref_point, acc);
+  if ( isnan(ret_val) ){
+    XLAL_ERROR(XLAL_FAILURE, "Interpolation error: gsl_spline_eval returning nan. Group name %s\n", groupName);
+  }
   gsl_vector_free(curr_t_vec);
   gsl_vector_free(curr_y_vec);
   gsl_spline_free (spline);
@@ -219,6 +231,9 @@ UNUSED static UINT4 XLALSimInspiralNRWaveformGetSpinsFromHDF5FilePointer(
 
     /* First interpolate between time and freq to get a reference time */
     ref_time = XLALSimInspiralNRWaveformGetRefTimeFromRefFreq(file, fRef);
+    REAL8 fminNR;
+    XLALH5FileQueryScalarAttributeValue(&fminNR, file, "f_lower_at_1MSUN");
+    XLAL_CHECK( ref_time!=XLAL_FAILURE, XLAL_FAILURE, "Error computing reference time. Try setting fRef equal to the f_low given by the NR simulation (%.16f Hz) or to a value <=0 to deactivate fRef for a non-precessing simulation.\n", fminNR/mTot);
 
     /* Now use ref_time to get spins, LN and nhat */
     nrSpin1x = XLALSimInspiralNRWaveformGetInterpValueFromGroupAtPoint
@@ -309,8 +324,9 @@ UNUSED static UINT4 XLALSimInspiralNRWaveformGetDataFromHDF5File(
   /* SPLINE STUFF */
   acc = gsl_interp_accel_alloc();
   spline = gsl_spline_alloc(gsl_interp_cspline, comp_data_length);
-  gsl_spline_init(spline, knotsVector->data, dataVector->data,
+  INT4 status = gsl_spline_init(spline, knotsVector->data, dataVector->data,
                   comp_data_length);
+  XLAL_CHECK(status == GSL_SUCCESS, XLAL_FAILURE, "Failed gsl_spline_init evaluation. Probably omega_w is not monotonically increasing.\n");
 
   for (idx = 0; idx < length; idx++)
   {
@@ -387,6 +403,7 @@ UNUSED static UINT4 XLALSimInspiralNRWaveformGetRotationAnglesFromH5File(
   {
     ref_time = XLALSimInspiralNRWaveformGetRefTimeFromRefFreq(filepointer,
                                                               fRef);
+    XLAL_CHECK( ref_time!=XLAL_FAILURE, XLAL_FAILURE, "Error computing reference time. Try setting fRef equal to the f_low given by the NR simulation or to a value <=0 to deactivate fRef for a non-precessing simulation.\n");
     ln_hat_x = XLALSimInspiralNRWaveformGetInterpValueFromGroupAtPoint
         (filepointer, "LNhatx-vs-time", ref_time);
     ln_hat_y = XLALSimInspiralNRWaveformGetInterpValueFromGroupAtPoint
@@ -647,14 +664,14 @@ UNUSED static INT4 XLALSimIMRNRWaveformGetModes(
         )
 {
 #ifndef LAL_HDF5_ENABLED
-  XLAL_ERROR_NULL(XLAL_FAILURE, "HDF5 support not enabled");
+  XLAL_ERROR(XLAL_EFAILED, "HDF5 support not enabled");
 #else
   /* Declarations */
   UINT4 curr_idx, nr_file_format;
   INT4 model, modem;
   size_t array_length;
   REAL8 nrEta;
-  REAL8 S1x, S1y, S1z, S2x, S2y, S2z;
+  REAL8 S1x = 0, S1y = 0, S1z = 0, S2x = 0, S2y = 0, S2z = 0;
   REAL8 Mflower, time_start_M, time_start_s, time_end_M, time_end_s;
   REAL8 est_start_time;
   REAL8 distance_scale_fac;
@@ -664,7 +681,7 @@ UNUSED static INT4 XLALSimIMRNRWaveformGetModes(
   /* These keys follow a strict formulation and cannot be longer than 11
    * characters */
   char amp_key[30];
-  char phase_key[30];
+  char phase_key[31];
   gsl_vector *tmpVector=NULL;
   LALH5File *group;
   LIGOTimeGPS tmpEpoch = LIGOTIMEGPSZERO;
@@ -687,6 +704,7 @@ UNUSED static INT4 XLALSimIMRNRWaveformGetModes(
   XLALSimInspiralNRWaveformGetSpinsFromHDF5FilePointer(&S1x, &S1y, &S1z,
                                                        &S2x, &S2y, &S2z,
                                                        fRef, m1+m2, file);
+  XLAL_CHECK(xlalErrno == 0, XLAL_EFUNC, "XLALSimInspiralNRWaveformGetSpinsFromHDF5FilePointer() failed");
 
   if (fabs(S1x - s1x) > 1E-3)
   {
@@ -756,7 +774,11 @@ UNUSED static INT4 XLALSimIMRNRWaveformGetModes(
     if (XLALSimInspiralNRWaveformCheckFRef(file, fStart * (m1+m2)) > 0)
     {
       /* Can use Omega array to get start time */
-      est_start_time = XLALSimInspiralNRWaveformGetRefTimeFromRefFreq(file, fStart * (m1+m2)) * (m1 + m2) * LAL_MTSUN_SI;
+      est_start_time = XLALSimInspiralNRWaveformGetRefTimeFromRefFreq(file, fStart * (m1+m2));
+      REAL8 fminNR;
+      XLALH5FileQueryScalarAttributeValue(&fminNR, file, "f_lower_at_1MSUN");
+      XLAL_CHECK( est_start_time!=XLAL_FAILURE, XLAL_FAILURE, "Error computing starting time. Try setting f_low equal to the f_low given by the NR simulation (%.16f Hz)\n",fminNR/(m1+m2));
+      est_start_time = est_start_time * (m1 + m2) * LAL_MTSUN_SI;
     }
     else
     {
@@ -1021,7 +1043,7 @@ INT4 XLALSimInspiralNRWaveformGetHlms(UNUSED SphHarmTimeSeries **Hlms, /**< OUTP
         )
 {
 #ifndef LAL_HDF5_ENABLED
-  XLAL_ERROR_NULL(XLAL_FAILURE, "HDF5 support not enabled");
+  XLAL_ERROR(XLAL_EFAILED, "HDF5 support not enabled");
 #else
   /* Declarations */
   UINT4 curr_idx, array_length, nr_file_format;
