@@ -13,8 +13,8 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with with program; see the file COPYING. If not, write to the
- *  Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
- *  MA  02111-1307  USA
+ *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA  02110-1301  USA
  */
 
 #include "LALSimIMRPhenomNSBH.h"
@@ -216,7 +216,7 @@ int IMRPhenomNSBH_Core(
     REAL8Sequence *planck_taper = XLALCreateREAL8Sequence(n_full);
     status = XLALSimNRTunedTidesFDTidalPhaseFrequencySeries(
         phi_tidal, amp_tidal, planck_taper, freqs,
-        mBH_SI, mNS_SI, 0.0, lambda_NS, NRTidalv2_V);
+        mBH_SI, mNS_SI, 0.0, lambda_NS, 0, 0, NRTidalv2_V);
     XLAL_CHECK(XLAL_SUCCESS == status, status, "XLALSimNRTunedTidesFDTidalPhaseFrequencySeries Failed.");
 
     const REAL8 amp0 = XLALSimPhenomUtilsFDamp0(M, distance);
