@@ -17,8 +17,8 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with with program; see the file COPYING. If not, write to the
- *  Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
- *  MA  02111-1307  USA
+ *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA  02110-1301  USA
  */
 
 #include "LALSimNRSurrogateUtilities.c"
@@ -162,18 +162,21 @@ typedef struct tagPrecessingNRSurData {
     UINT4 PrecessingNRSurVersion;   /**< 0 for NRSur7dq2, 1 for NRSur7dq4 */
 } PrecessingNRSurData;
 
-
 /***********************************************************************************/
 /****************************** Function declarations*******************************/
 /***********************************************************************************/
-static void NRSur7dq2_Init_LALDATA(void);
-static void NRSur7dq4_Init_LALDATA(void);
+UNUSED static void NRSur7dq2_Init_LALDATA(void);
+UNUSED static void NRSur7dq4_Init_LALDATA(void);
+
+#ifdef LAL_HDF5_ENABLED
 static int PrecessingNRSur_Init(PrecessingNRSurData *data, LALH5File *file, UINT4 PrecessingNRSurVersion);
 static void PrecessingNRSur_LoadFitData(FitData **fit_data, LALH5File *sub, const char *name);
 static void NRSur7dq4_LoadVectorFitData(VectorFitData **vector_fit_data, LALH5File *sub, const char *name, const size_t size);
 static void PrecessingNRSur_LoadDynamicsNode(DynamicsNodeFitData **ds_node_data, LALH5File *sub, int i, UINT4 PrecessingNRSurVersion);
 static void PrecessingNRSur_LoadCoorbitalEllModes(WaveformFixedEllModeData **coorbital_mode_data, LALH5File *file, int i);
 static void PrecessingNRSur_LoadWaveformDataPiece(LALH5File *sub, WaveformDataPiece **data, bool invert_sign);
+#endif
+
 static bool NRSur7dq2_IsSetup(void);
 static bool NRSur7dq4_IsSetup(void);
 static double ipow(double base, int exponent); // integer powers
