@@ -14,8 +14,8 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with with program; see the file COPYING. If not, write to the
- *  Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
- *  MA  02111-1307  USA
+ *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA  02110-1301  USA
  */
 
 #ifdef __GNUC__
@@ -506,13 +506,13 @@ int SEOBNRROMdataDS_Init(
   XLALH5FileClose(file);
 
   ret |= SEOBNRROMdataDS_Init_submodel(&(romdata)->sub1, dir, "sub1");
-  if (ret==XLAL_SUCCESS) XLALPrintInfo("%s : submodel 1 loaded sucessfully.\n", __func__);
+  if (ret==XLAL_SUCCESS) XLALPrintInfo("%s : submodel 1 loaded successfully.\n", __func__);
 
   ret |= SEOBNRROMdataDS_Init_submodel(&(romdata)->sub2, dir, "sub2");
-  if (ret==XLAL_SUCCESS) XLALPrintInfo("%s : submodel 2 loaded sucessfully.\n", __func__);
+  if (ret==XLAL_SUCCESS) XLALPrintInfo("%s : submodel 2 loaded successfully.\n", __func__);
 
   ret |= SEOBNRROMdataDS_Init_submodel(&(romdata)->sub3, dir, "sub3");
-  if (ret==XLAL_SUCCESS) XLALPrintInfo("%s : submodel 3 loaded sucessfully.\n", __func__);
+  if (ret==XLAL_SUCCESS) XLALPrintInfo("%s : submodel 3 loaded successfully.\n", __func__);
 
   if(XLAL_SUCCESS==ret)
     romdata->setup=1;
@@ -1470,16 +1470,41 @@ int XLALSimIMRSEOBNRv4ROMTimeOfFrequency(
   }
 
   // Set up phase spline
-  gsl_spline *spline_phi;
-  gsl_interp_accel *acc_phi;
-  double Mf_final, Mtot_sec;
-  double Mf_ROM_min, Mf_ROM_max;
+  gsl_spline *spline_phi = NULL;
+  gsl_interp_accel *acc_phi = NULL;
+  double Mf_final = NAN, Mtot_sec;
+  double Mf_ROM_min = NAN, Mf_ROM_max = NAN;
   int ret = SEOBNRv4ROMTimeFrequencySetup(&spline_phi, &acc_phi, &Mf_final,
                                           &Mtot_sec, m1SI, m2SI, chi1, chi2,
                                           &Mf_ROM_min, &Mf_ROM_max);
   if(ret != 0)
     XLAL_ERROR(ret);
 
+  if (spline_phi == NULL) {
+    XLALPrintError( "XLAL Error - %s: `spline_phi` is not initialized\n", __func__);
+    XLAL_ERROR( XLAL_EFAULT );
+  }
+
+  if (acc_phi == NULL) {
+    XLALPrintError( "XLAL Error - %s: `acc_phi` is not initialized\n", __func__);
+    XLAL_ERROR( XLAL_EFAULT );
+  }
+
+  if (isnan(Mf_final)) {
+    XLALPrintError( "XLAL Error - %s: `Mf_final` is not initialized\n", __func__);
+    XLAL_ERROR( XLAL_EFAULT );
+  }
+
+  if (isnan(Mf_ROM_min)) {
+    XLALPrintError( "XLAL Error - %s: `Mf_ROM_min` is not initialized\n", __func__);
+    XLAL_ERROR( XLAL_EFAULT );
+  }
+
+  if (isnan(Mf_ROM_max)) {
+    XLALPrintError( "XLAL Error - %s: `Mf_ROM_max` is not initialized\n", __func__);
+    XLAL_ERROR( XLAL_EFAULT );
+  }
+
   // Time correction is t(f_final) = 1/(2pi) dphi/df (f_final)
   double t_corr = gsl_spline_eval_deriv(spline_phi, Mf_final, acc_phi) / (2*LAL_PI); // t_corr / M
   //XLAL_PRINT_INFO("t_corr[s] = %g\n", t_corr * Mtot_sec);
@@ -1488,7 +1513,8 @@ int XLALSimIMRSEOBNRv4ROMTimeOfFrequency(
   if (Mf < Mf_ROM_min || Mf > Mf_ROM_max || Mf > Mf_final) {
     gsl_spline_free(spline_phi);
     gsl_interp_accel_free(acc_phi);
-    XLAL_ERROR(XLAL_EDOM, "Frequency %g is outside allowed frequency range.\n", frequency);
+    XLAL_ERROR(XLAL_EDOM, "Frequency %g Hz (Mf=%g) is outside allowed range.\n"
+               "Min / max / final Mf values are %g, %g, %g\n", frequency, Mf, Mf_ROM_min, Mf_ROM_max, Mf_final);
    }
 
   // Compute time relative to origin at merger
@@ -1537,16 +1563,41 @@ int XLALSimIMRSEOBNRv4ROMFrequencyOfTime(
   }
 
   // Set up phase spline
-  gsl_spline *spline_phi;
-  gsl_interp_accel *acc_phi;
-  double Mf_final, Mtot_sec;
-  double Mf_ROM_min, Mf_ROM_max;
+  gsl_spline *spline_phi = NULL;
+  gsl_interp_accel *acc_phi = NULL;
+  double Mf_final = NAN, Mtot_sec;
+  double Mf_ROM_min = NAN, Mf_ROM_max = NAN;
   int ret = SEOBNRv4ROMTimeFrequencySetup(&spline_phi, &acc_phi, &Mf_final,
                                           &Mtot_sec, m1SI, m2SI, chi1, chi2,
                                           &Mf_ROM_min, &Mf_ROM_max);
   if(ret != 0)
     XLAL_ERROR(ret);
 
+  if (spline_phi == NULL) {
+    XLALPrintError( "XLAL Error - %s: `spline_phi` is not initialized\n", __func__);
+    XLAL_ERROR( XLAL_EFAULT );
+  }
+
+  if (acc_phi == NULL) {
+    XLALPrintError( "XLAL Error - %s: `acc_phi` is not initialized\n", __func__);
+    XLAL_ERROR( XLAL_EFAULT );
+  }
+
+  if (isnan(Mf_final)) {
+    XLALPrintError( "XLAL Error - %s: `Mf_final` is not initialized\n", __func__);
+    XLAL_ERROR( XLAL_EFAULT );
+  }
+
+  if (isnan(Mf_ROM_min)) {
+    XLALPrintError( "XLAL Error - %s: `Mf_ROM_min` is not initialized\n", __func__);
+    XLAL_ERROR( XLAL_EFAULT );
+  }
+
+  if (isnan(Mf_ROM_max)) {
+    XLALPrintError( "XLAL Error - %s: `Mf_ROM_max` is not initialized\n", __func__);
+    XLAL_ERROR( XLAL_EFAULT );
+  }
+
   // Time correction is t(f_final) = 1/(2pi) dphi/df (f_final)
   double t_corr = gsl_spline_eval_deriv(spline_phi, Mf_final, acc_phi) / (2*LAL_PI); // t_corr / M
   //XLAL_PRINT_INFO("t_corr[s] = %g\n", t_corr * Mtot_sec);
@@ -1602,7 +1653,7 @@ UNUSED static void SEOBNRv4ROM_Init_LALDATA(void)
   // Expect ROM datafile in a directory listed in LAL_DATA_PATH,
 #ifdef LAL_HDF5_ENABLED
 #define datafile ROMDataHDF5
-  char *path = XLALFileResolvePathLong(datafile, PKG_DATA_DIR);
+  char *path = XLAL_FILE_RESOLVE_PATH(datafile);
   if (path==NULL)
     XLAL_ERROR_VOID(XLAL_EIO, "Unable to resolve data file %s in $LAL_DATA_PATH\n", datafile);
   char *dir = dirname(path);
