@@ -14,8 +14,8 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with with program; see the file COPYING. If not, write to the
- *  Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
- *  MA  02111-1307  USA
+ *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA  02110-1301  USA
  */
 
 #ifdef __GNUC__
@@ -33,7 +33,6 @@
 #include <alloca.h>
 #include <string.h>
 #include <libgen.h>
-#include <assert.h>
 
 #include <gsl/gsl_errno.h>
 #include <gsl/gsl_bspline.h>
@@ -235,7 +234,7 @@ static int TaylorF2Amplitude1PN(
 UNUSED static void save_gsl_frequency_series(const char filename[], gsl_vector *x, gsl_vector *y) {
   FILE *fp = fopen(filename, "w");
   fprintf(stderr, "save_gsl_frequency_series: %s: %zu %zu\n", filename, x->size, y->size);
-  assert(x->size == y->size);
+  XLAL_CHECK_ABORT(x->size == y->size);
   for (size_t i=0; i<x->size; i++) {
     fprintf(fp, "%g\t%g\n", gsl_vector_get(x, i), gsl_vector_get(y, i));
   }
@@ -1292,7 +1291,7 @@ UNUSED static void Surrogate_Init_LALDATA(void)
   // Expect ROM datafile in a directory listed in LAL_DATA_PATH,
 #ifdef LAL_HDF5_ENABLED
 #define datafile SurDataHDF5
-  char *path = XLALFileResolvePathLong(datafile, PKG_DATA_DIR);
+  char *path = XLAL_FILE_RESOLVE_PATH(datafile);
   if (path==NULL)
     XLAL_ERROR_VOID(XLAL_EIO, "Unable to resolve data file %s in $LAL_DATA_PATH\n", datafile);
   char *dir = dirname(path);
