@@ -13,8 +13,8 @@
 *
 *  You should have received a copy of the GNU General Public License
 *  along with with program; see the file COPYING. If not, write to the
-*  Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-*  MA  02111-1307  USA
+*  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+*  MA  02110-1301  USA
 */
 
 
@@ -720,7 +720,7 @@ static int XLALSimIMREOBCalcCalibCoefficientHigherModes (FacWaveformCoeffs *
                      v = cbrt (orbOmegaVec->data[i]);
                      if (XLALSimIMRSpinEOBGetSpinFactorizedWaveform
                          (&(hLMVec->data[i]), values, v, HamVec->data[i], modeL, modeM, params,
-                         0) == XLAL_FAILURE)
+                         params->postAdiabaticFlag) == XLAL_FAILURE)
                      {
                        if(hLMVec) XLALDestroyCOMPLEX16Vector(hLMVec);
                        if(rholmpwrlVec) XLALDestroyCOMPLEX16Vector(rholmpwrlVec);
@@ -1327,7 +1327,7 @@ XLALSimIMRSpinEOBFluxGetSpinFactorizedWaveform (COMPLEX16 * restrict hlm,
  * Concerning SEOBNRv4 see also https://dcc.ligo.org/T1600383
  */
 
-static int XLALSimIMREOBCalcSpinFacWaveformCoefficients (FacWaveformCoeffs * const coeffs,
+UNUSED static int XLALSimIMREOBCalcSpinFacWaveformCoefficients (FacWaveformCoeffs * const coeffs,
               /**< OUTPUT, pre-computed waveform coefficients */
               SpinEOBParams * restrict params,
               /**< Others parameters like use_hm */
@@ -2164,7 +2164,6 @@ XLALSimIMRSpinEOBGetSpinFactorizedWaveform (COMPLEX16 * restrict hlm,
   INT4 i;
   INT4 use_hm = 0;
 
-
   REAL8 eta;
   REAL8 r, pp, Omega, v2, vh, vh3, k, hathatk, eulerlogxabs;	//pr
   REAL8 Slm, deltalm, rholm;
