@@ -13,8 +13,8 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with with program; see the file COPYING. If not, write to the
- *  Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
- *  MA  02111-1307  USA
+ *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA  02110-1301  USA
  */
 
 #include <math.h>
@@ -70,18 +70,18 @@ typedef struct
 } expnCoeffsTaylorT1;
 
 typedef REAL8 (SimInspiralTaylorT1Energy)(
-	REAL8 v, /**< post-Newtonian parameter */
-	expnCoeffsdEnergyFlux *ak
+	REAL8 v,                   /**< post-Newtonian parameter */
+	expnCoeffsdEnergyFlux *ak  /**< Taylor expansion coefficents */
 );
 
 typedef REAL8 (SimInspiralTaylorT1dEnergy)(
-	REAL8 v, /**< post-Newtonian parameter */
-	expnCoeffsdEnergyFlux *ak
+	REAL8 v,                   /**< post-Newtonian parameter */
+	expnCoeffsdEnergyFlux *ak  /**< Taylor expansion coefficents */
 );
 
 typedef REAL8 (SimInspiralTaylorT1Flux)(
-	REAL8 v, /**< post-Newtonian parameter */
-	expnCoeffsdEnergyFlux *ak
+	REAL8 v,                   /**< post-Newtonian parameter */
+	expnCoeffsdEnergyFlux *ak  /**< Taylor expansion coefficents */
 );
 
 /*
