@@ -13,8 +13,8 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with with program; see the file COPYING. If not, write to the
- *  Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
- *  MA  02111-1307  USA
+ *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA  02110-1301  USA
  */
 
 #include <math.h>
@@ -60,13 +60,13 @@ tagexpnCoeffsTaylorT4 {
 }expnCoeffsTaylorT4;
 
 typedef REAL8 (SimInspiralEnergy4)(
-   REAL8 v, /**< post-Newtonian parameter */
-   expnCoeffsdEnergyFlux *ak
+   REAL8 v,                   /**< post-Newtonian parameter */
+   expnCoeffsdEnergyFlux *ak  /**< Taylor expansion coefficients */
 );
 
 typedef REAL8 (SimInspiralAngularAcceleration4)(
-   REAL8 v, /**< post-Newtonian parameter */
-   expnCoeffsTaylorT4 *ak
+   REAL8 v,                /**< post-Newtonian parameter */
+   expnCoeffsTaylorT4 *ak  /**< Taylor expansion coefficients */
 );
 
 /*
