@@ -13,8 +13,8 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with with program; see the file COPYING. If not, write to the
- *  Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
- *  MA  02111-1307  USA
+ *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA  02110-1301  USA
  */
 
 /**
@@ -37,14 +37,16 @@
 
 #include "LALSimNRHybSurUtilities.h"
 
-#include <assert.h>
 #include <gsl/gsl_bspline.h>
 #include <gsl/gsl_blas.h>
 #include <gsl/gsl_spline.h>
 #include <gsl/gsl_complex_math.h>
 
 #include <lal/SeqFactories.h>
+
+#ifdef LAL_HDF5_ENABLED
 #include <lal/H5FileIO.h>
+#endif
 
 #include <lal/XLALError.h>
 #include <lal/LALConstants.h>
@@ -60,7 +62,7 @@
 
 
 
-
+#ifdef LAL_HDF5_ENABLED
 //********************* H5 wrapper functions ************************/
 
 /**
@@ -86,7 +88,6 @@ int ReadHDF5DoubleDataset(
     return XLAL_SUCCESS;
 }
 
-
 /**
  * Reads an INT8 value from a H5 file/group.
  */
@@ -111,9 +112,6 @@ int ReadHDF5IntDataset(
 }
 
 
-
-
-
 //********************* Surrogate loading functions ************************/
 // These should only be called once, when initializing the surrogate
 
@@ -139,8 +137,11 @@ static int NRHybSur_LoadDataPiece(
     sub = XLALH5GroupOpen(file, sub_grp_name);
     *data_piece = XLALMalloc(sizeof(DataPiece));
 
+
     gsl_matrix *ei_basis = NULL;
+
     int ret = ReadHDF5RealMatrixDataset(sub, "ei_basis", &ei_basis);
+
     if (ret != XLAL_SUCCESS) {
         XLAL_ERROR(XLAL_EFUNC, "Failed to load ei_basis.");
     }
@@ -164,7 +165,7 @@ static int NRHybSur_LoadDataPiece(
     for (int i=0; i<n_nodes; i++) {
 
         nwritten = snprintf(node_name, str_size, "node_num_%d", i);
-        assert(nwritten < str_size);
+        XLAL_CHECK_ABORT(nwritten < str_size);
         LALH5File *node_function = XLALH5GroupOpen(sub, node_name);
         NRHybSurFitData *fit_data = XLALMalloc(sizeof(NRHybSurFitData));
 
@@ -206,7 +207,6 @@ static int NRHybSur_LoadDataPiece(
             XLAL_ERROR(XLAL_EFUNC, "Failed to load lin_intercept.");
         }
 
-
         // Load arrays needed for fit
         hyperparams->length_scale = NULL;
         ret = ReadHDF5RealVectorDataset(node_function, "length_scale",
@@ -289,7 +289,7 @@ static int NRHybSur_LoadSingleModeData(
 
         // Amplitude of 22 mode
         nwritten = snprintf(sub_grp_name, str_size, "l%u_m%u/amp", ell, m);
-        assert(nwritten < str_size);
+        XLAL_CHECK_ABORT(nwritten < str_size);
         ret = NRHybSur_LoadDataPiece(&(data_pieces)->ampl_data_piece,
                 file, sub_grp_name);
         if(ret != XLAL_SUCCESS) {
@@ -300,7 +300,7 @@ static int NRHybSur_LoadSingleModeData(
 
         // phase of 22 mode
         nwritten = snprintf(sub_grp_name, str_size, "l%u_m%u/phase", ell, m);
-        assert(nwritten < str_size);
+        XLAL_CHECK_ABORT(nwritten < str_size);
         ret = NRHybSur_LoadDataPiece(&(data_pieces)->phase_res_data_piece,
                 file, sub_grp_name);
         if(ret != XLAL_SUCCESS) {
@@ -316,7 +316,7 @@ static int NRHybSur_LoadSingleModeData(
         if (m != 0 || ell % 2 == 0) {
             // Real part of coorbital frame mode
             nwritten = snprintf(sub_grp_name, str_size, "l%u_m%u/re", ell, m);
-            assert(nwritten < str_size);
+            XLAL_CHECK_ABORT(nwritten < str_size);
             ret = NRHybSur_LoadDataPiece(&(data_pieces)->coorb_re_data_piece,
                     file, sub_grp_name);
             if(ret != XLAL_SUCCESS) {
@@ -332,7 +332,7 @@ static int NRHybSur_LoadSingleModeData(
         if (m != 0 || ell % 2 == 1) {
             // Imaginary part of coorbital frame mode
             nwritten = snprintf(sub_grp_name, str_size, "l%u_m%u/im", ell, m);
-            assert(nwritten < str_size);
+            XLAL_CHECK_ABORT(nwritten < str_size);
             ret = NRHybSur_LoadDataPiece(&(data_pieces)->coorb_im_data_piece,
                     file, sub_grp_name);
             if(ret != XLAL_SUCCESS) {
@@ -348,7 +348,6 @@ static int NRHybSur_LoadSingleModeData(
     return ret;
 }
 
-
 /**
  * Initialize a NRHybSurData structure from an open H5 file.
  * This will typically only be called once.
@@ -490,10 +489,10 @@ int NRHybSur_Init(
     if (ret == XLAL_SUCCESS){
         NR_hybsur_data->setup = 1;
     }
-
+    
     return ret;
 }
-
+#endif
 
 
 
