@@ -17,23 +17,23 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with with program; see the file COPYING. If not, write to the
-# Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-# MA 02111-1307 USA
+# Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+# MA 02110-1301 USA
 
-id = "c27f04763bf863346cace6941add5c3b631049f1"
-date = "2020-07-22 13:40:31 +0000"
+id = "5fd08c4d441c0684ae5ab3bffaad442240e30461"
+date = "2024-08-20 15:10:39 +0000"
 branch = "None"
-tag = "lalsimulation-v2.2.0"
+tag = "lalsimulation-v6.0.0"
 if tag == "None":
     tag = None
 author = "Adam Mercer <adam.mercer@ligo.org>"
 builder = "Adam Mercer <adam.mercer@ligo.org>"
-committer = "Adam Mercer <ramercer@gmail.com>"
+committer = "Adam Mercer <adam.mercer@ligo.org>"
 status = "CLEAN: All modifications committed"
 version = id
 verbose_msg = """Branch: None
-Tag: lalsimulation-v2.2.0
-Id: c27f04763bf863346cace6941add5c3b631049f1
+Tag: lalsimulation-v6.0.0
+Id: 5fd08c4d441c0684ae5ab3bffaad442240e30461
 
 Builder: Adam Mercer <adam.mercer@ligo.org>
 Repository status: CLEAN: All modifications committed"""
@@ -54,9 +54,9 @@ def check_match(foreign_id, onmismatch="raise"):
     """
     if onmismatch not in ("raise", "warn"):
         raise ValueError(onmismatch + " is an unrecognized value of onmismatch")
-    if foreign_id == "c27f04763bf863346cace6941add5c3b631049f1":
+    if foreign_id == "5fd08c4d441c0684ae5ab3bffaad442240e30461":
         return
-    msg = "Program id (c27f04763bf863346cace6941add5c3b631049f1) does not match given id (%s)." % foreign_id
+    msg = "Program id (5fd08c4d441c0684ae5ab3bffaad442240e30461) does not match given id (%s)." % foreign_id
     if onmismatch == "raise":
         raise VersionMismatchError(msg)
 
